package com.ipsplm.dao.simulation;

import com.ipsplm.entity.simulation.*;
import com.ipsplm.entity.simulation.vo.BufferVO;
import com.ipsplm.entity.simulation.vo.PlantEquipmentUtilizationVO;
import com.ipsplm.entity.simulation.vo.FieldCnVO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @Description 仿真分析Mapper层
 * @Author lulicheng
 * @Date 2024-07-31 10：22
 * @Version 1.0
 */
@Mapper
public interface SimulationAnalysisMapper {
    /**
     * 获取厂房设备利用率信息
     * @param flag
     * @return
     */
    List<PlantEquipmentUtilizationVO> getPlantEquipmentUtilization(Long flag);

    /**
     * 获取不锈钢OEE
     * @return
     */
    List<OeeBxg> getOeeBxg();

    /**
     * 获取大径线OEE
     * @return
     */
    List<OeeDj> getOeeDj();

    /**
     * 获取小二线OEE
     * @return
     */
    List<OeeXe> getOeeXe();

    /**
     * 获取小一线OEE
     * @return
     */
    List<OeeXy> getOeeXy();

    /**
     * 获取中二线OEE
     * @return
     */
    List<OeeZe> getOeeZe();

    /**
     * 获取中一线OEE
     * @return
     */
    List<OeeZy> getOeeZy();

    /**
     * 获取工序列表
     * @param tableCode
     * @return
     */
    List<String> getProcessList(String tableCode);

    /**
     * 获取缓存信息
     * @param process
     * @return
     */
    List<BufferVO> getBufferName(String process);

    /**
     * 获取不锈钢缓存数量
     * @param bufferNameList
     * @return
     */
    List<BufferNumBxg> getBufferNumBxg(@Param("bufferNameList") List<BufferVO> bufferNameList);

    /**
     * 获取大径线缓存数量
     * @param bufferNameList
     * @return
     */
    List<BufferNumDj> getBufferNumDj(@Param("bufferNameList") List<BufferVO> bufferNameList);

    /**
     * 获取小二线缓存数量
     * @param bufferNameList
     * @return
     */
    List<BufferNumXe> getBufferNumXe(@Param("bufferNameList") List<BufferVO> bufferNameList);

    /**
     * 获取小一线缓存数量
     * @param bufferNameList
     * @return
     */
    List<BufferNumXy> getBufferNumXy(@Param("bufferNameList") List<BufferVO> bufferNameList);

    /**
     * 获取中二线缓存数量
     * @param bufferNameList
     * @return
     */
    List<BufferNumZe> getBufferNumZe(@Param("bufferNameList") List<BufferVO> bufferNameList);

    /**
     * 获取中一线缓存数量
     * @param bufferNameList
     * @return
     */
    List<BufferNumZy> getBufferNumZy(@Param("bufferNameList") List<BufferVO> bufferNameList);

    /**
     * 获取字段信息
     * @param tableId
     * @param groupId
     * @return
     */
    List<FieldCnVO> getFieldInfo(@Param("tableId") Integer tableId,@Param("groupId") Integer groupId);

    /**
     * 获取仿真结束时间
     * @return
     */
    String getSimEndTime();
}
