package com.ipsplm.service.simulation.impl;

import cn.hutool.json.JSONUtil;
import com.ipsplm.service.simulation.ISimulationService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.*;
import java.net.Socket;

/**
 * @Description 仿真Service实现类
 * @Author FanDongqiang
 * @Date 2023/3/15 16:26
 * @Version 1.0
 */
@Service
@Slf4j
public class SimulationServiceImpl implements ISimulationService {

    @Value("${plant.socket.ip}")
    private String ip;

    @Value("${plant.socket.port}")
    private Integer port;

    /**
     * 获取仿真数据
     *
     * @param param 仿真参数
     */
    @Override
    public String getPlantData(Object param) {
        Socket socket = null;
        String receivedMessage = null;
        try {
            // 创建Socket对象，指定服务端的IP地址和端口号
            socket = new Socket(ip, port);

            // 获取输入流和输出流 输入流和输出流是通过socket对象来进行数据传输的。
            InputStream inputStream = socket.getInputStream();
            OutputStream outputStream = socket.getOutputStream();
            OutputStreamWriter outputStreamWriter = new OutputStreamWriter(outputStream);
            BufferedWriter bufferedWriter = new BufferedWriter(outputStreamWriter);
//            PrintWriter writer = new PrintWriter(outputStream, true);

            // 将用户输入的信息发送给服务端
//            writer.println(param);
            bufferedWriter.write((String) param);
            bufferedWriter.flush();
            long oldTime = System.currentTimeMillis();
            // 接收服务端的响应并打印
            long newTime = System.currentTimeMillis();
            // 接收服务器发送的消息
            byte[] buffer = new byte[1024];
            int length = inputStream.read(buffer);
            receivedMessage = new String(buffer, 0, length);
            if(newTime-oldTime > 210 * 1000) {
                receivedMessage = "请求超时";
                log.info("请求超时");
            }else {
                if (StringUtils.isNotEmpty(receivedMessage)) {
                    System.out.println("收到服务器发送的消息：" + receivedMessage);
                        return receivedMessage;

                }
            }
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (socket != null) {
                try {
                    // 关闭连接
                    socket.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return receivedMessage;
    }
}
